meson: A high performance build system
======================================

Description
-----------

A high performance build system

License
-------

Apache License, Version 2.0

Upstream Contact
----------------

https://pypi.org/project/meson/

